@@ -65,10 +65,10 @@ def _alternative_calibration_folder(base_dir: Path) -> Path:
 
 def get_all_participants(include_bad_data: bool = False, *, base_dir: Optional[Path] = None) -> List[str]:
     """Get the folder names of all participants."""
-    all_participants = sorted([f.name.split("_")[0] for f in _raw_data_folder(base_dir).glob("*_left.dat")])
+    all_participants = [f.name.split("_")[0] for f in _raw_data_folder(base_dir).glob("*_left.dat")]
     if include_bad_data:
-        return all_participants
-    return list(set(all_participants) - set(BAD_DATA))
+        return sorted(all_participants)
+    return sorted(set(all_participants) - set(BAD_DATA))
 
 
 def get_all_data_for_participant(
